package controllers

import (
	"encoding/json"
	sealReq "hongze/hongze_mobile_admin/models/request/seal"
	sealResp "hongze/hongze_mobile_admin/models/response/seal"
	"hongze/hongze_mobile_admin/services/seal"
	sealService "hongze/hongze_mobile_admin/services/seal"
	"hongze/hongze_mobile_admin/utils"
)

//用印模块
type SealCommon struct {
	BaseAuth
}

// @Title 新增用印
// @Description 新增用印接口
// @Param	request	body sealReq.AddReq true "type json string"
// @Success Ret=200 新增用印成功
// @router /add [post]
func (this *SealCommon) Add() {
	var req sealReq.AddReq
	err := json.Unmarshal(this.Ctx.Input.RequestBody, &req)
	if err != nil {
		this.FailWithMessage("参数解析异常！", "参数解析失败，Err:"+err.Error())
		return
	}

	//参数校验
	paramVerify := utils.Rules{
		"Use":         {utils.NotEmpty()},
		"CompanyName": {utils.NotEmpty()},
		"CreditCode":  {utils.NotEmpty()},
		"ServiceType": {utils.NotEmpty()},
		"SealType":    {utils.NotEmpty()},
		"FileUrl":     {utils.NotEmpty()},
	}
	err = utils.Verify(req, paramVerify, utils.LANG_CN)

	if err != nil {
		this.FailWithMessage("缺少参数", err.Error())
		return
	}
	sealInfo, err := seal.AddSeal(this.AdminWx.AdminId, this.AdminWx.RealName, req.Use, req.CompanyName, req.CreditCode, req.ServiceType, req.SealType, req.Remark, req.FileUrl)
	if err != nil {
		this.FailWithMessage("用印添加失败", err.Error())
		return
	}

	msg := "添加用印成功"
	if req.IsAudit {
		err = sealService.Apply(sealInfo)
		if err != nil {
			this.FailWithMessage("发起用印审批失败", "发起用印审批失败，Err:"+err.Error())
			return
		}
		msg = "发起用印审批成功"
	}
	this.OkDetailed(sealResp.AddSealResp{
		SealId: sealInfo.SealId,
	}, msg)
}

// @Title 编辑用印
// @Description 编辑用印接口
// @Param	request	body request.EditContractReq true "type json string"
// @Success 200 {object} response.AddContractResp
// @router /edit [post]
func (this *SealCommon) Edit() {
	var req sealReq.EditReq
	err := json.Unmarshal(this.Ctx.Input.RequestBody, &req)
	if err != nil {
		this.FailWithMessage("参数解析异常！", "参数解析失败，Err:"+err.Error())
		return
	}

	//参数校验
	paramVerify := utils.Rules{
		"SealId":      {utils.NotEmpty()},
		"Use":         {utils.NotEmpty()},
		"CompanyName": {utils.NotEmpty()},
		"CreditCode":  {utils.NotEmpty()},
		"ServiceType": {utils.NotEmpty()},
		"SealType":    {utils.NotEmpty()},
		"FileUrl":     {utils.NotEmpty()},
	}
	err = utils.Verify(req, paramVerify, utils.LANG_CN)

	if req.SealId <= 0 {
		this.FailWithMessage("合同编号必传！", "合同编号必传！")
		return
	}
	sealInfo, err := seal.Edit(req.SealId, this.AdminWx.AdminId, this.AdminWx.RealName, req.Use, req.CompanyName, req.CreditCode, req.ServiceType, req.SealType, req.Remark, req.FileUrl)
	if err != nil {
		this.FailWithMessage("修改合同失败！", "修改合同失败，Err:"+err.Error())
		return
	}
	msg := "修改成功"
	//如果发起重新审核，那么
	if req.ReAudit {
		tmpErr := sealService.Apply(sealInfo)
		if tmpErr != nil {
			this.FailWithMessage("发起重申失败！", "发起重申失败，Err:"+tmpErr.Error())
			return
		}
		msg = "发起重申成功"
	}
	this.OkDetailed(sealResp.AddSealResp{
		SealId: sealInfo.SealId,
	}, msg)
}
