package contract

import (
	"hongze/hongze_mobile_admin/models/custom/contract"
	"hongze/hongze_mobile_admin/models/tables/company_contract"
	"hongze/hongze_mobile_admin/models/tables/contract_approval"
	"rdluck_tools/paging"
	"time"
)

type CompanyContractDetailResp struct {
	*company_contract.CompanyContractDetail
}

type ContractOperationRecordListResp struct {
	Id               int       ``
	ContractId       int       `description:"合同id"`
	Operation        string    `description:"操作类型，add：新增，edit：编辑，apply：发起审批，cancel_apply：撤回审批，reject：拒绝审批，approval：审批操作;长度36位"`
	OpUserId         int       `description:"操作人id"`
	OpUserName       string    `description:"操作人名称"`
	Remark           string    `description:"备注，长度255位"`
	ApprovalRecordId int       `orm:"column(approval_record_id)";description:"审批流id"`
	CreateTime       time.Time `description:"日志添加时间"`
	CreateTimeStr    string    `description:"日志添加时间"`
}

//审批列表
type ContractApprovalListResp struct {
	Paging *paging.PagingItem
	List   []*contract_approval.ContractApprovalList `description:"列表数据"`
}

//合同详情信息（包含服务信息等）
type ContractDetail struct {
	ContractId     int       `description:"合同唯一id"`
	ContractCode   string    `description:"合同编号,长度32位"`
	SellerId       int       `description:"所属销售id"`
	SellerName     string    `description:"所属销售名称"`
	ProductId      int       `description:"产品id，1：ficc；2：权益"`
	ContractType   string    `description:"合同类型，枚举值：'新签合同','续约合同','补充协议'"`
	Status         string    `description:"合同状态，枚举值：'待提交','待审批','已撤回','已审批','已驳回','已作废'"`
	StartDate      time.Time `description:"合同开始日期"`
	EndDate        time.Time `description:"合同结束日期"`
	OriginalPrice  float64   `description:"合同原金额，优惠前的金额"`
	Price          float64   `description:"实际金额，优惠后的金额"`
	PayRemark      string    `description:"付款方式说明,长度255位"`
	CompanyName    string    `description:"客户名称，甲方名称,长度32位"`
	CreditCode     string    `description:"社会统一信用代码,长度64位"`
	ProvinceId     int       `description:"省级id"`
	Province       string    `description:"省级名称,长度16位"`
	CityId         int       `description:"市级id"`
	City           string    `description:"市级名称,长度32位"`
	Address        string    `description:"详细地址"`
	Fax            string    `description:"传真,长度32位"`
	Phone          string    `description:"电话,长度32位"`
	Postcode       string    `description:"邮编,长度16位"`
	Remark         string    `description:"补充内容,长度255位"`
	ModifyContent  string    `description:"修改内容"`
	ApprovalRemark string    `description:"审核备注"`
	FileUrl        string    `description:"合同文件地址"`
	TemplateId     int       `description:"模板id"`
	SourceId       int       `description:"来源合同id，默认是0；如果是通过其他合同复制过来的，那么就是原合同的id"`
	IsDelete       int       `json:"-";description:"是否已经删除，0：未删除，1：已删除"`
	ModifyTime     time.Time `description:"合同最近一次修改时间"`
	CreateTime     time.Time `description:"合同添加时间"`

	StartDateStr  string `description:"合同起始时间"`
	EndDateStr    string `description:"合同结束时间"`
	ModifyTimeStr string `description:"最近一次更新时间"`
	CreateTimeStr string `description:"合同添加时间"`
	Service       []*contract.ContractServiceAndDetail
}
