package seal

import (
	"fmt"
	"hongze/hongze_mobile_admin/utils"
	"rdluck_tools/orm"
	"time"
)

//用印
type Seal struct {
	SealId         int       `orm:"column(seal_id);pk"`
	Code           string    `description:"用印编号,长度32位"`
	UserId         int       `description:"申请人id"`
	UserName       string    `description:"申请人名称"`
	Use            string    `description:"用印用途，枚举值：'销售合同', '渠道合同', '付款通知函', '招投标', '战略合作协议'；默认：销售合同"`
	CompanyName    string    `description:"客户名称，甲方名称,长度32位"`
	CreditCode     string    `description:"社会统一信用代码,长度64位"`
	ServiceType    string    `description:"业务类型，枚举值：'新增业务', '续约业务', '补充协议'；默认：新增业务"`
	SealType       string    `description:"加盖印章类型，枚举值：'合同章', '公章', '法人章';默认：合同章"`
	Status         string    `description:"合同状态，枚举值：'待提交','待审批','已撤回','已审批','已驳回','已作废'"`
	Remark         string    `description:"补充内容,长度255位"`
	ApprovalRemark string    `description:"审核备注"`
	FileUrl        string    `description:"文件附件地址"`
	IsDelete       int       `description:"是否已经删除，0：未删除，1：已删除",json:"-"`
	ModifyTime     time.Time `description:"最近一次修改时间"`
	CreateTime     time.Time `description:"添加时间"`
}

//根据合同id获取合同信息
func GetSealInfoById(sealId int) (sealInfo *Seal, err error) {
	o := orm.NewOrm()
	sql := `select * from seal where seal_id = ? `
	err = o.Raw(sql, sealId).QueryRow(&sealInfo)
	return
}

//用印添加
func AddSeal(sealInfo *Seal) (err error) {
	o := orm.NewOrm()
	//用印数据入库
	sealId, err := o.Insert(sealInfo)
	if err != nil {
		return
	}
	sealInfo.SealId = int(sealId)
	return
}

//更新用印信息
func (seal *Seal) Update(cols []string) (err error) {
	o := orm.NewOrm()
	_, err = o.Update(seal, cols...)
	return
}

//删除用印
func DeleteSeal(sealInfo *Seal) (err error) {
	sealInfo.IsDelete = 1
	sealInfo.ModifyTime = time.Now()
	err = sealInfo.Update([]string{"IsDelete", "ModifyTime"})
	return
}

//作废用印
func InvalidSeal(sealInfo *Seal) (err error) {
	sealInfo.Status = "已作废"
	sealInfo.ModifyTime = time.Now()
	//修改用印数据入库
	err = sealInfo.Update([]string{"IsDelete", "ModifyTime"})
	return
}

//生成合同编号
func GetSealCode() (code string, err error) {
	var num int
	o := orm.NewOrm()
	today := utils.GetToday(utils.FormatDate)
	sql := `SELECT COUNT(1) AS num FROM seal where create_time>=?`
	err = o.Raw(sql, today).QueryRow(&num)
	if err != nil {
		return
	}

	code = "HZ" + time.Now().Format("20060102") + fmt.Sprintf("%03d", num)
	return
}
