// @APIVersion 1.0.0
// @Title 弘则手机端管理后台接口
// @Description 这是弘则手机端管理后台接口api文档，统一出、入参；出参格式：{"code":200,"data":{},"msg":"操作成功","errMsg":"开发人员查看的错误信息"}，code是业务响应码，200 代表正常返回；400 代表业务处理失败，前端同学需要做额外逻辑处理；401 代表token异常，用户需要重新静默授权，获取最新的token；403代表用户需要进行绑定操作，需要跳转到输入账号密码绑定页面。同时如果出现其他返回值（没有在约定范围内），那么及时联系后端同事；msg是用来提示前端同学，一般只在code为 400 的情况下才会展示给用户去看；data是业务返回数据，给前端做逻辑处理。
// 除了微信静默授权接口，其他所有接口请求都必须在header中携带token
// @Contact astaxie@gmail.com
// @TermsOfServiceUrl http://beego.me/
// @License Apache 2.0
// @LicenseUrl http://www.apache.org/licenses/LICENSE-2.0.html
package routers

import (
	"github.com/astaxie/beego/plugins/cors"
	"hongze/hongze_mobile_admin/controllers"

	"github.com/astaxie/beego"
)

func init() {
	//解决跨域问题
	beego.InsertFilter("*", beego.BeforeRouter, cors.Allow(&cors.Options{
		AllowAllOrigins:  true,
		AllowMethods:     []string{"GET", "POST", "PUT", "DELETE", "OPTIONS"},
		AllowHeaders:     []string{"Origin", "Authorization", "Access-Control-Allow-Origin", "Access-Control-Allow-Headers", "Content-Type"},
		ExposeHeaders:    []string{"Content-Length", "Access-Control-Allow-Origin", "Access-Control-Allow-Headers", "Content-Type"},
		AllowCredentials: true,
	}))
	ns := beego.NewNamespace("/h5adminapi",
		beego.NSNamespace("/wechat",
			beego.NSInclude(
				&controllers.WeChatCommon{},
			),
		),
		beego.NSNamespace("/admin",
			beego.NSInclude(
				&controllers.AdminCommon{},
			),
		),
		beego.NSNamespace("/approval",
			beego.NSInclude(
				&controllers.ApprovalCommon{},
			),
		),
		beego.NSNamespace("/message",
			beego.NSInclude(
				&controllers.MessageCommon{},
			),
		),
		beego.NSNamespace("/company_contract",
			beego.NSInclude(
				&controllers.CompanyContractCommon{},
			),
		),
		beego.NSNamespace("/contract",
			beego.NSInclude(
				&controllers.ContractCommon{},
			),
		),
		beego.NSNamespace("/contract_approval",
			beego.NSInclude(
				&controllers.ContractApprovalCommon{},
			),
		),
	)
	beego.AddNamespace(ns)
}
