package contract

import (
	"errors"
	"fmt"
	"hongze/hongze_mobile_admin/models/custom"
	contractCustom "hongze/hongze_mobile_admin/models/custom/contract"
	"hongze/hongze_mobile_admin/models/tables/contract"
	"hongze/hongze_mobile_admin/models/tables/contract_operation_record"
	"hongze/hongze_mobile_admin/models/tables/contract_service_detail"
	"hongze/hongze_mobile_admin/utils"
)

//根据id获取合同详情（包含服务）
func GetContractDetail(contractId int) (contractDetail *contract.ContractDetail, err error) {
	contractDetail, err = contract.GetContractDetailById(contractId)
	if err != nil {
		if err.Error() == utils.ErrNoRow() {
			err = errors.New("找不到该合同")
		}
		return
	}
	serviceList, err := contractCustom.GetContractServiceAndDetailList(contractId)
	if err != nil {
		err = errors.New(fmt.Sprint("查找合同服务异常", err))
		return
	}
	for i := 0; len(serviceList) > i; i++ {
		if serviceList[i].HasDetail == "是" {
			list, detailErr := contract_service_detail.GetContractServiceDetailListByServiceId(serviceList[i].ContractServiceId)
			if detailErr != nil {
				err = errors.New(fmt.Sprint("查找合同服务详情异常", detailErr))
				return
			}
			serviceList[i].DetailList = list
		}
	}
	contractDetail.Service = serviceList
	return
}

//上传签回合同附件
func UploadCheckBackFile(contractId int, fileUrl string, opUser *custom.AdminWx) (err error) {
	//获取合同信息
	contractInfo, err := contract.GetContractById(contractId)
	if err != nil {
		return
	}
	//合同状态判断
	if contractInfo.Status != "已审批" && contractInfo.Status != "已签回" {
		err = errors.New("合同状态异常，不允许上传签回合同附件，当前合同状态：" + contractInfo.Status)
		return
	}
	contractInfo.CheckBackFileUrl = fileUrl
	contractInfo.Status = "已签回"
	var updateCol = []string{"CheckBackFileUrl", "Status"}
	contractInfo.Update(updateCol)

	//添加操作日志
	remark := "上传签回合同附件"
	_ = contract_operation_record.AddContractOperationRecord(contractInfo.ContractId, opUser.AdminId, 0, "upload", opUser.RealName, remark)
	return
}
